import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MfaPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Policy Description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#description MfaPolicy#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#duo MfaPolicy#duo}.
     *
     * @stability stable
     */
    readonly duo?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#external_idp MfaPolicy#external_idp}.
     *
     * @stability stable
     */
    readonly externalIdp?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#fido_u2f MfaPolicy#fido_u2f}.
     *
     * @stability stable
     */
    readonly fidoU2F?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#fido_webauthn MfaPolicy#fido_webauthn}.
     *
     * @stability stable
     */
    readonly fidoWebauthn?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#google_otp MfaPolicy#google_otp}.
     *
     * @stability stable
     */
    readonly googleOtp?: {
        [key: string]: string;
    };
    /**
     * List of Group IDs to Include.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#groups_included MfaPolicy#groups_included}
     *
     * @stability stable
     */
    readonly groupsIncluded?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#hotp MfaPolicy#hotp}.
     *
     * @stability stable
     */
    readonly hotp?: {
        [key: string]: string;
    };
    /**
     * Is the policy using Okta Identity Engine (OIE) with authenticators instead of factors?
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#is_oie MfaPolicy#is_oie}
     *
     * @stability stable
     */
    readonly isOie?: boolean | cdktf.IResolvable;
    /**
     * Policy Name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#name MfaPolicy#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_call MfaPolicy#okta_call}.
     *
     * @stability stable
     */
    readonly oktaCall?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_email MfaPolicy#okta_email}.
     *
     * @stability stable
     */
    readonly oktaEmail?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_otp MfaPolicy#okta_otp}.
     *
     * @stability stable
     */
    readonly oktaOtp?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_password MfaPolicy#okta_password}.
     *
     * @stability stable
     */
    readonly oktaPassword?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_push MfaPolicy#okta_push}.
     *
     * @stability stable
     */
    readonly oktaPush?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_question MfaPolicy#okta_question}.
     *
     * @stability stable
     */
    readonly oktaQuestion?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_sms MfaPolicy#okta_sms}.
     *
     * @stability stable
     */
    readonly oktaSms?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#okta_verify MfaPolicy#okta_verify}.
     *
     * @stability stable
     */
    readonly oktaVerify?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#onprem_mfa MfaPolicy#onprem_mfa}.
     *
     * @stability stable
     */
    readonly onpremMfa?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#phone_number MfaPolicy#phone_number}.
     *
     * @stability stable
     */
    readonly phoneNumber?: {
        [key: string]: string;
    };
    /**
     * Policy Priority, this attribute can be set to a valid priority.
     *
     * To avoid endless diff situation we error if an invalid priority is provided. API defaults it to the last (lowest) if not there.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#priority MfaPolicy#priority}
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#rsa_token MfaPolicy#rsa_token}.
     *
     * @stability stable
     */
    readonly rsaToken?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#security_question MfaPolicy#security_question}.
     *
     * @stability stable
     */
    readonly securityQuestion?: {
        [key: string]: string;
    };
    /**
     * Policy Status: ACTIVE or INACTIVE.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#status MfaPolicy#status}
     *
     * @stability stable
     */
    readonly status?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#symantec_vip MfaPolicy#symantec_vip}.
     *
     * @stability stable
     */
    readonly symantecVip?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#webauthn MfaPolicy#webauthn}.
     *
     * @stability stable
     */
    readonly webauthn?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy#yubikey_token MfaPolicy#yubikey_token}.
     *
     * @stability stable
     */
    readonly yubikeyToken?: {
        [key: string]: string;
    };
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy okta_mfa_policy}.
 *
 * @stability stable
 */
export declare class MfaPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/okta/r/mfa_policy okta_mfa_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MfaPolicyConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _duo?;
    /**
     * @stability stable
     */
    get duo(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set duo(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetDuo(): void;
    /**
     * @stability stable
     */
    get duoInput(): {
        [key: string]: string;
    } | undefined;
    private _externalIdp?;
    /**
     * @stability stable
     */
    get externalIdp(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set externalIdp(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetExternalIdp(): void;
    /**
     * @stability stable
     */
    get externalIdpInput(): {
        [key: string]: string;
    } | undefined;
    private _fidoU2F?;
    /**
     * @stability stable
     */
    get fidoU2F(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set fidoU2F(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetFidoU2F(): void;
    /**
     * @stability stable
     */
    get fidoU2FInput(): {
        [key: string]: string;
    } | undefined;
    private _fidoWebauthn?;
    /**
     * @stability stable
     */
    get fidoWebauthn(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set fidoWebauthn(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetFidoWebauthn(): void;
    /**
     * @stability stable
     */
    get fidoWebauthnInput(): {
        [key: string]: string;
    } | undefined;
    private _googleOtp?;
    /**
     * @stability stable
     */
    get googleOtp(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set googleOtp(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetGoogleOtp(): void;
    /**
     * @stability stable
     */
    get googleOtpInput(): {
        [key: string]: string;
    } | undefined;
    private _groupsIncluded?;
    /**
     * @stability stable
     */
    get groupsIncluded(): string[];
    /**
     * @stability stable
     */
    set groupsIncluded(value: string[]);
    /**
     * @stability stable
     */
    resetGroupsIncluded(): void;
    /**
     * @stability stable
     */
    get groupsIncludedInput(): string[] | undefined;
    private _hotp?;
    /**
     * @stability stable
     */
    get hotp(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set hotp(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetHotp(): void;
    /**
     * @stability stable
     */
    get hotpInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _isOie?;
    /**
     * @stability stable
     */
    get isOie(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isOie(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsOie(): void;
    /**
     * @stability stable
     */
    get isOieInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _oktaCall?;
    /**
     * @stability stable
     */
    get oktaCall(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaCall(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaCall(): void;
    /**
     * @stability stable
     */
    get oktaCallInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaEmail?;
    /**
     * @stability stable
     */
    get oktaEmail(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaEmail(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaEmail(): void;
    /**
     * @stability stable
     */
    get oktaEmailInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaOtp?;
    /**
     * @stability stable
     */
    get oktaOtp(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaOtp(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaOtp(): void;
    /**
     * @stability stable
     */
    get oktaOtpInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaPassword?;
    /**
     * @stability stable
     */
    get oktaPassword(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaPassword(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaPassword(): void;
    /**
     * @stability stable
     */
    get oktaPasswordInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaPush?;
    /**
     * @stability stable
     */
    get oktaPush(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaPush(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaPush(): void;
    /**
     * @stability stable
     */
    get oktaPushInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaQuestion?;
    /**
     * @stability stable
     */
    get oktaQuestion(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaQuestion(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaQuestion(): void;
    /**
     * @stability stable
     */
    get oktaQuestionInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaSms?;
    /**
     * @stability stable
     */
    get oktaSms(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaSms(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaSms(): void;
    /**
     * @stability stable
     */
    get oktaSmsInput(): {
        [key: string]: string;
    } | undefined;
    private _oktaVerify?;
    /**
     * @stability stable
     */
    get oktaVerify(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set oktaVerify(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOktaVerify(): void;
    /**
     * @stability stable
     */
    get oktaVerifyInput(): {
        [key: string]: string;
    } | undefined;
    private _onpremMfa?;
    /**
     * @stability stable
     */
    get onpremMfa(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set onpremMfa(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetOnpremMfa(): void;
    /**
     * @stability stable
     */
    get onpremMfaInput(): {
        [key: string]: string;
    } | undefined;
    private _phoneNumber?;
    /**
     * @stability stable
     */
    get phoneNumber(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set phoneNumber(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetPhoneNumber(): void;
    /**
     * @stability stable
     */
    get phoneNumberInput(): {
        [key: string]: string;
    } | undefined;
    private _priority?;
    /**
     * @stability stable
     */
    get priority(): number;
    /**
     * @stability stable
     */
    set priority(value: number);
    /**
     * @stability stable
     */
    resetPriority(): void;
    /**
     * @stability stable
     */
    get priorityInput(): number | undefined;
    private _rsaToken?;
    /**
     * @stability stable
     */
    get rsaToken(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set rsaToken(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRsaToken(): void;
    /**
     * @stability stable
     */
    get rsaTokenInput(): {
        [key: string]: string;
    } | undefined;
    private _securityQuestion?;
    /**
     * @stability stable
     */
    get securityQuestion(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set securityQuestion(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetSecurityQuestion(): void;
    /**
     * @stability stable
     */
    get securityQuestionInput(): {
        [key: string]: string;
    } | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
    private _symantecVip?;
    /**
     * @stability stable
     */
    get symantecVip(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set symantecVip(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetSymantecVip(): void;
    /**
     * @stability stable
     */
    get symantecVipInput(): {
        [key: string]: string;
    } | undefined;
    private _webauthn?;
    /**
     * @stability stable
     */
    get webauthn(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set webauthn(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetWebauthn(): void;
    /**
     * @stability stable
     */
    get webauthnInput(): {
        [key: string]: string;
    } | undefined;
    private _yubikeyToken?;
    /**
     * @stability stable
     */
    get yubikeyToken(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set yubikeyToken(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetYubikeyToken(): void;
    /**
     * @stability stable
     */
    get yubikeyTokenInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
