import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface UserSchemaPropertyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Custom Subschema enumerated value of a property of type array.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#array_enum UserSchemaProperty#array_enum}
     *
     * @stability stable
     */
    readonly arrayEnum?: string[];
    /**
     * Subschema array type: string, number, integer, reference. Type field must be an array.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#array_type UserSchemaProperty#array_type}
     *
     * @stability stable
     */
    readonly arrayType?: string;
    /**
     * Custom Subschema description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#description UserSchemaProperty#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Custom Subschema enumerated value of the property. see: developer.okta.com/docs/api/resources/schemas#user-profile-schema-property-object.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#enum UserSchemaProperty#enum}
     *
     * @stability stable
     */
    readonly enum?: string[];
    /**
     * Subschema external name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#external_name UserSchemaProperty#external_name}
     *
     * @stability stable
     */
    readonly externalName?: string;
    /**
     * Subschema external namespace.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#external_namespace UserSchemaProperty#external_namespace}
     *
     * @stability stable
     */
    readonly externalNamespace?: string;
    /**
     * Subschema unique string identifier.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#index UserSchemaProperty#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * SubSchema profile manager, if not set it will inherit its setting.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#master UserSchemaProperty#master}
     *
     * @stability stable
     */
    readonly master?: string;
    /**
     * Subschema of type string maximum length.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#max_length UserSchemaProperty#max_length}
     *
     * @stability stable
     */
    readonly maxLength?: number;
    /**
     * Subschema of type string minimum length.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#min_length UserSchemaProperty#min_length}
     *
     * @stability stable
     */
    readonly minLength?: number;
    /**
     * The validation pattern to use for the subschema. Must be in form of '.+', or '[<pattern>]+' if present.'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#pattern UserSchemaProperty#pattern}
     *
     * @stability stable
     */
    readonly pattern?: string;
    /**
     * SubSchema permissions: HIDE, READ_ONLY, or READ_WRITE.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#permissions UserSchemaProperty#permissions}
     *
     * @stability stable
     */
    readonly permissions?: string;
    /**
     * Whether the subschema is required.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#required UserSchemaProperty#required}
     *
     * @stability stable
     */
    readonly required?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#scope UserSchemaProperty#scope}.
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * Subschema title (display name).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#title UserSchemaProperty#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Subschema type: string, boolean, number, integer, array, or object.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#type UserSchemaProperty#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Subschema unique restriction.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#unique UserSchemaProperty#unique}
     *
     * @stability stable
     */
    readonly unique?: string;
    /**
     * Custom subschema user type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#user_type UserSchemaProperty#user_type}
     *
     * @stability stable
     */
    readonly userType?: string;
    /**
     * array_one_of block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#array_one_of UserSchemaProperty#array_one_of}
     *
     * @stability stable
     */
    readonly arrayOneOf?: UserSchemaPropertyArrayOneOf[] | cdktf.IResolvable;
    /**
     * master_override_priority block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#master_override_priority UserSchemaProperty#master_override_priority}
     *
     * @stability stable
     */
    readonly masterOverridePriority?: UserSchemaPropertyMasterOverridePriority[] | cdktf.IResolvable;
    /**
     * one_of block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#one_of UserSchemaProperty#one_of}
     *
     * @stability stable
     */
    readonly oneOf?: UserSchemaPropertyOneOf[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface UserSchemaPropertyArrayOneOf {
    /**
     * Enum value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#const UserSchemaProperty#const}
     *
     * @stability stable
     */
    readonly const: string;
    /**
     * Enum title.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#title UserSchemaProperty#title}
     *
     * @stability stable
     */
    readonly title: string;
}
export declare function userSchemaPropertyArrayOneOfToTerraform(struct?: UserSchemaPropertyArrayOneOf | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface UserSchemaPropertyMasterOverridePriority {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#type UserSchemaProperty#type}.
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#value UserSchemaProperty#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function userSchemaPropertyMasterOverridePriorityToTerraform(struct?: UserSchemaPropertyMasterOverridePriority | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface UserSchemaPropertyOneOf {
    /**
     * Enum value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#const UserSchemaProperty#const}
     *
     * @stability stable
     */
    readonly const: string;
    /**
     * Enum title.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property#title UserSchemaProperty#title}
     *
     * @stability stable
     */
    readonly title: string;
}
export declare function userSchemaPropertyOneOfToTerraform(struct?: UserSchemaPropertyOneOf | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property okta_user_schema_property}.
 *
 * @stability stable
 */
export declare class UserSchemaProperty extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/okta/r/user_schema_property okta_user_schema_property} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: UserSchemaPropertyConfig);
    private _arrayEnum?;
    /**
     * @stability stable
     */
    get arrayEnum(): string[];
    /**
     * @stability stable
     */
    set arrayEnum(value: string[]);
    /**
     * @stability stable
     */
    resetArrayEnum(): void;
    /**
     * @stability stable
     */
    get arrayEnumInput(): string[] | undefined;
    private _arrayType?;
    /**
     * @stability stable
     */
    get arrayType(): string;
    /**
     * @stability stable
     */
    set arrayType(value: string);
    /**
     * @stability stable
     */
    resetArrayType(): void;
    /**
     * @stability stable
     */
    get arrayTypeInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enum?;
    /**
     * @stability stable
     */
    get enum(): string[];
    /**
     * @stability stable
     */
    set enum(value: string[]);
    /**
     * @stability stable
     */
    resetEnum(): void;
    /**
     * @stability stable
     */
    get enumInput(): string[] | undefined;
    private _externalName?;
    /**
     * @stability stable
     */
    get externalName(): string;
    /**
     * @stability stable
     */
    set externalName(value: string);
    /**
     * @stability stable
     */
    resetExternalName(): void;
    /**
     * @stability stable
     */
    get externalNameInput(): string | undefined;
    private _externalNamespace?;
    /**
     * @stability stable
     */
    get externalNamespace(): string;
    /**
     * @stability stable
     */
    set externalNamespace(value: string);
    /**
     * @stability stable
     */
    resetExternalNamespace(): void;
    /**
     * @stability stable
     */
    get externalNamespaceInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _master?;
    /**
     * @stability stable
     */
    get master(): string;
    /**
     * @stability stable
     */
    set master(value: string);
    /**
     * @stability stable
     */
    resetMaster(): void;
    /**
     * @stability stable
     */
    get masterInput(): string | undefined;
    private _maxLength?;
    /**
     * @stability stable
     */
    get maxLength(): number;
    /**
     * @stability stable
     */
    set maxLength(value: number);
    /**
     * @stability stable
     */
    resetMaxLength(): void;
    /**
     * @stability stable
     */
    get maxLengthInput(): number | undefined;
    private _minLength?;
    /**
     * @stability stable
     */
    get minLength(): number;
    /**
     * @stability stable
     */
    set minLength(value: number);
    /**
     * @stability stable
     */
    resetMinLength(): void;
    /**
     * @stability stable
     */
    get minLengthInput(): number | undefined;
    private _pattern?;
    /**
     * @stability stable
     */
    get pattern(): string;
    /**
     * @stability stable
     */
    set pattern(value: string);
    /**
     * @stability stable
     */
    resetPattern(): void;
    /**
     * @stability stable
     */
    get patternInput(): string | undefined;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): string;
    /**
     * @stability stable
     */
    set permissions(value: string);
    /**
     * @stability stable
     */
    resetPermissions(): void;
    /**
     * @stability stable
     */
    get permissionsInput(): string | undefined;
    private _required?;
    /**
     * @stability stable
     */
    get required(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set required(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequired(): void;
    /**
     * @stability stable
     */
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _scope?;
    /**
     * @stability stable
     */
    get scope(): string;
    /**
     * @stability stable
     */
    set scope(value: string);
    /**
     * @stability stable
     */
    resetScope(): void;
    /**
     * @stability stable
     */
    get scopeInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _unique?;
    /**
     * @stability stable
     */
    get unique(): string;
    /**
     * @stability stable
     */
    set unique(value: string);
    /**
     * @stability stable
     */
    resetUnique(): void;
    /**
     * @stability stable
     */
    get uniqueInput(): string | undefined;
    private _userType?;
    /**
     * @stability stable
     */
    get userType(): string;
    /**
     * @stability stable
     */
    set userType(value: string);
    /**
     * @stability stable
     */
    resetUserType(): void;
    /**
     * @stability stable
     */
    get userTypeInput(): string | undefined;
    private _arrayOneOf?;
    /**
     * @stability stable
     */
    get arrayOneOf(): UserSchemaPropertyArrayOneOf[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set arrayOneOf(value: UserSchemaPropertyArrayOneOf[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetArrayOneOf(): void;
    /**
     * @stability stable
     */
    get arrayOneOfInput(): cdktf.IResolvable | UserSchemaPropertyArrayOneOf[] | undefined;
    private _masterOverridePriority?;
    /**
     * @stability stable
     */
    get masterOverridePriority(): UserSchemaPropertyMasterOverridePriority[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set masterOverridePriority(value: UserSchemaPropertyMasterOverridePriority[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMasterOverridePriority(): void;
    /**
     * @stability stable
     */
    get masterOverridePriorityInput(): cdktf.IResolvable | UserSchemaPropertyMasterOverridePriority[] | undefined;
    private _oneOf?;
    /**
     * @stability stable
     */
    get oneOf(): UserSchemaPropertyOneOf[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set oneOf(value: UserSchemaPropertyOneOf[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOneOf(): void;
    /**
     * @stability stable
     */
    get oneOfInput(): cdktf.IResolvable | UserSchemaPropertyOneOf[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
